SWDEV-339657 - Update catch codes with correct coordinates (#2735)

Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
This commit is contained in:
ROCm CI Service Account
2022-06-15 23:28:10 +05:30
committed by GitHub
parent 0b05268be2
commit d31aca651d
8 changed files with 19 additions and 19 deletions
@@ -230,19 +230,19 @@ __device__ __host__ struct printInfo startPrint(uint32_t tid,
// This kernel is launched only in X dimension
__global__ void kernel_complex_opX(uint32_t *a, uint32_t *b,
uint32_t iterCount) {
uint32_t tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint32_t tid = threadIdx.x + blockIdx.x * blockDim.x;
startPrint(tid, iterCount, a, b);
}
// This kernel is launched only in Y dimension
__global__ void kernel_complex_opY(uint32_t *a, uint32_t *b,
uint32_t iterCount) {
uint32_t tid = hipThreadIdx_y + hipBlockIdx_y * hipBlockDim_y;
uint32_t tid = threadIdx.y + blockIdx.y * blockDim.y;
startPrint(tid, iterCount, a, b);
}
// This kernel is launched only in Z dimension
__global__ void kernel_complex_opZ(uint32_t *a, uint32_t *b,
uint32_t iterCount) {
uint32_t tid = hipThreadIdx_z + hipBlockIdx_z * hipBlockDim_z;
uint32_t tid = threadIdx.z + blockIdx.z * blockDim.z;
startPrint(tid, iterCount, a, b);
}
#ifdef __linux__